summaryrefslogtreecommitdiffstats
path: root/filters/kword/oowriter/oowriterimport.cc
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-21 14:05:41 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-21 14:05:41 -0600
commit2d6954f69caf63ed5057bd8e1405a65d7d970292 (patch)
tree88e6436b2e81d4e68313f02a9021054252e14cc4 /filters/kword/oowriter/oowriterimport.cc
parentf0de9e167e289ab7dc33e57f077c1f04ec7c68c8 (diff)
downloadkoffice-2d6954f69caf63ed5057bd8e1405a65d7d970292.tar.gz
koffice-2d6954f69caf63ed5057bd8e1405a65d7d970292.zip
Rename obsolete tq methods to standard names
Diffstat (limited to 'filters/kword/oowriter/oowriterimport.cc')
-rw-r--r--filters/kword/oowriter/oowriterimport.cc14
1 files changed, 7 insertions, 7 deletions
diff --git a/filters/kword/oowriter/oowriterimport.cc b/filters/kword/oowriter/oowriterimport.cc
index 3f267bebc..07262c861 100644
--- a/filters/kword/oowriter/oowriterimport.cc
+++ b/filters/kword/oowriter/oowriterimport.cc
@@ -873,13 +873,13 @@ void OoWriterImport::writeCounter( TQDomDocument& doc, TQDomElement& layoutEleme
TQString bulletChar = listStyle.attributeNS( ooNS::text, "bullet-char", TQString() );
if ( !bulletChar.isEmpty() ) {
#if 0 // doesn't work well. Fonts lack those symbols!
- counter.setAttribute( "bullet", bulletChar[0].tqunicode() );
- kdDebug(30518) << "bullet code " << bulletChar[0].tqunicode() << endl;
+ counter.setAttribute( "bullet", bulletChar[0].unicode() );
+ kdDebug(30518) << "bullet code " << bulletChar[0].unicode() << endl;
TQString fontName = listStyleProperties.attributeNS( ooNS::style, "font-name", TQString() );
counter.setAttribute( "bulletfont", fontName );
#endif
// Reverse engineering, I found those codes:
- switch( bulletChar[0].tqunicode() ) {
+ switch( bulletChar[0].unicode() ) {
case 0x2022: // small disc
counter.setAttribute( "type", 10 ); // a disc bullet
break;
@@ -1209,12 +1209,12 @@ TQDomElement OoWriterImport::parseParagraph( TQDomDocument& doc, const TQDomElem
TQDomElement* paragraphStyle = m_styles[paragraph.attributeNS( ooNS::text, "style-name", TQString() )];
TQString masterPageName = paragraphStyle ? paragraphStyle->attributeNS( ooNS::style, "master-page-name", TQString() ) : TQString();
if ( masterPageName.isEmpty() )
- masterPageName = "Standard"; // Seems to be a builtin name for the default tqlayout...
+ masterPageName = "Standard"; // Seems to be a builtin name for the default layout...
if ( masterPageName != m_currentMasterPage )
{
// Detected a change in the master page -> this means we have to use a new page tqlayout
// and insert a frame break if not on the first paragraph.
// In KWord we don't support sections so the first paragraph is the one that determines the page tqlayout.
if ( m_currentMasterPage.isEmpty() ) {
m_currentMasterPage = masterPageName; // before writePageLayout to avoid recursion
writePageLayout( doc, masterPageName );
@@ -1228,7 +1228,7 @@ TQDomElement OoWriterImport::parseParagraph( TQDomDocument& doc, const TQDomElem
layoutElement.appendChild( pageBreakElem );
}
pageBreakElem.setAttribute( "hardFrameBreak", "true" );
// We have no way to store the new page tqlayout, KWord doesn't have sections.
}
}
@@ -1209,12 +1209,12 @@ TQDomElement OoWriterImport::parseParagraph( TQDomDocument& doc, const TQDomElem
if ( masterPageName != m_currentMasterPage )
{
- // Detected a change in the master page -> this means we have to use a new page tqlayout
+ // Detected a change in the master page -> this means we have to use a new page layout
// and insert a frame break if not on the first paragraph.
@@ -1209,12 +1209,12 @@ TQDomElement OoWriterImport::parseParagraph( TQDomDocument& doc, const TQDomElem
// and insert a frame break if not on the first paragraph.
- // In KWord we don't support sections so the first paragraph is the one that determines the page tqlayout.
+ // In KWord we don't support sections so the first paragraph is the one that determines the page layout.
if ( m_currentMasterPage.isEmpty() ) {
m_currentMasterPage = masterPageName; // before writePageLayout to avoid recursion
@@ -1228,7 +1228,7 @@ TQDomElement OoWriterImport::parseParagraph( TQDomDocument& doc, const TQDomElem
}
pageBreakElem.setAttribute( "hardFrameBreak", "true" );
- // We have no way to store the new page tqlayout, KWord doesn't have sections.
+ // We have no way to store the new page layout, KWord doesn't have sections.
}
}